#
# spec file for package agama
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           agama
#               This will be set by osc services, that will run after this.
Version:        10+717
Release:        10.1
Summary:        Agama Installer
#               If you know the license, put it's SPDX string here.
#               Alternately, you can use cargo lock2rpmprovides to help generate this.
License:        GPL-2.0-or-later
URL:            https://github.com/opensuse/agama
Source0:        agama.tar
Source1:        vendor.tar.zst

BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(openssl)
# used in tests for dbus service
BuildRequires:  dbus-1-common
Requires:       dbus-1-common
# required by agama-dbus-server integration tests
BuildRequires:  dbus-1-daemon
BuildRequires:  clang-devel
BuildRequires:  pkgconfig(pam)
# required by autoinstallation
BuildRequires:  jsonnet
Requires:       jsonnet
Requires:       lshw
# required by "agama logs store"
Requires:       gzip
# required to compress the manual pages
Requires:       tar
# required for translating the keyboards descriptions
BuildRequires:  xkeyboard-config-lang
Requires:       xkeyboard-config-lang
# required for getting the list of timezones
Requires:       timezone
BuildRequires:  timezone
# required for getting the languages information
BuildRequires:  python-langtable-data
Requires:       python-langtable-data
# dependency on the YaST part of Agama
Requires:       agama-yast

# conflicts with the old packages
Conflicts:      agama-dbus-server

%description
Agama is a service-based Linux installer. It is composed of an HTTP-based API,
a web user interface, a command-line interface and a D-Bus service which exposes
part of the YaST libraries.

%package -n agama-cli
#               This will be set by osc services, that will run after this.
Version:        10+717
Release:        10.1
Summary:        Agama command-line interface
License:        GPL-2.0-only
URL:            https://github.com/opensuse/agama

%description -n agama-cli
Command line program to interact with the Agama installer.

%package -n agama-cli-bash-completion
Summary:        Bash Completion for %{name}-cli
Group:          System/Shells
Supplements:    (%{name}-cli and bash-completion)
Requires:       %{name}-cli = %{version}
Requires:       bash-completion
BuildArch:      noarch

%description -n agama-cli-bash-completion
Bash command-line completion support for %{name}.

%package -n agama-cli-fish-completion
Summary:        Fish Completion for %{name}-cli
Group:          System/Shells
Supplements:    (%{name}-cli and fish)
Requires:       %{name}-cli = %{version}
Requires:       fish
BuildArch:      noarch

%description -n agama-cli-fish-completion
Fish command-line completion support for %{name}-cli.

%package -n agama-cli-zsh-completion
Summary:        Zsh Completion for %{name}-cli
Group:          System/Shells
Supplements:    (%{name}-cli and zsh)
Requires:       %{name}-cli = %{version}
Requires:       zsh
BuildArch:      noarch

%description -n agama-cli-zsh-completion
Zsh command-line completion support for %{name}-cli.

%package -n agama-openapi
Summary:        Agama's OpenAPI Specification

%description -n agama-openapi
The OpenAPI Specification (OAS) allows describing an HTTP API in an standard and
language-agnostic way. This package contains the specification for Agama's HTTP
API.

%package -n agama-scripts
Summary:        Agama support for running user-defined scripts

%description -n agama-scripts
The Agama installer supports running user-defined scripts during and after the installation. This
package contains a systemd service to run scripts when booting the installed system.

%prep
%autosetup -a1 -n agama
# Remove exec bits to prevent an issue in fedora shebang checking. Uncomment only if required.
# find vendor -type f -name \*.rs -exec chmod -x '{}' \;

%build
%{cargo_build}
cargo run --package xtask -- manpages
gzip out/man/*
cargo run --package xtask -- completions
cargo run --package xtask -- openapi

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/agama/target/release/agama %{buildroot}%{_bindir}/agama
install -m 0755 %{_builddir}/agama/target/release/agama-dbus-server %{buildroot}%{_bindir}/agama-dbus-server
install -m 0755 %{_builddir}/agama/target/release/agama-web-server %{buildroot}%{_bindir}/agama-web-server
install -D -p -m 644 %{_builddir}/agama/share/agama.pam $RPM_BUILD_ROOT%{_pam_vendordir}/agama
install -D -d -m 0755 %{buildroot}%{_datadir}/agama-cli
install -m 0644 %{_builddir}/agama/agama-lib/share/profile.schema.json %{buildroot}%{_datadir}/agama-cli
install -m 0644 %{_builddir}/agama/share/agama.libsonnet %{buildroot}%{_datadir}/agama-cli
install --directory %{buildroot}%{_datadir}/dbus-1/agama-services
install -m 0644 --target-directory=%{buildroot}%{_datadir}/dbus-1/agama-services %{_builddir}/agama/share/org.opensuse.Agama1.service
install -D -m 0644 %{_builddir}/agama/share/agama-web-server.service %{buildroot}%{_unitdir}/agama-web-server.service
install -D -d -m 0755 %{buildroot}%{_libexecdir}
install -D -m 0755 %{_builddir}/agama/share/agama-scripts.sh %{buildroot}%{_libexecdir}/agama-scripts.sh
install -D -m 0644 %{_builddir}/agama/share/agama-scripts.service %{buildroot}%{_unitdir}/agama-scripts.service

# install manpages
mkdir -p %{buildroot}%{_mandir}/man1
install -m 0644 %{_builddir}/agama/out/man/* %{buildroot}%{_mandir}/man1/

# install shell completion scripts
install -Dm644 %{_builddir}/agama/out/shell/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 %{_builddir}/agama/out/shell/_%{name} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm644 %{_builddir}/agama/out/shell/%{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

# install OpenAPI specification
mkdir -p %{buildroot}%{_datadir}/agama/openapi
install -m 0644 %{_builddir}/agama/out/openapi/* %{buildroot}%{_datadir}/agama/openapi

%check
PATH=$PWD/share/bin:$PATH
%ifarch aarch64
/usr/bin/cargo auditable test -j1 --offline --no-fail-fast
%else
echo $PATH
%{cargo_test}
%endif

%pre
%service_add_pre agama-web-server.service

%pre -n agama-scripts
%service_add_pre agama-scripts.service

%post
%service_add_post agama-web-server.service

%post -n agama-scripts
%service_add_post agama-scripts.service

%preun
%service_del_preun agama-web-server.service

%preun -n agama-scripts
%service_del_preun agama-scripts.service

%postun
%service_del_postun_with_restart agama-web-server.service

%postun -n agama-scripts
%service_del_postun_with_restart agama-scripts.service

%files
%doc README.md
%license LICENSE
%{_bindir}/agama-dbus-server
%{_bindir}/agama-web-server
%{_datadir}/dbus-1/agama-services
%{_pam_vendordir}/agama
%{_unitdir}/agama-web-server.service

%files -n agama-cli
%{_bindir}/agama
%dir %{_datadir}/agama-cli
%{_datadir}/agama-cli/agama.libsonnet
%{_datadir}/agama-cli/profile.schema.json
%{_mandir}/man1/agama*1%{?ext_man}

%files -n agama-cli-bash-completion
%{_datadir}/bash-completion/*

%files -n agama-cli-fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files -n agama-cli-zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%files -n agama-openapi
%dir %{_datadir}/agama
%dir %{_datadir}/agama/openapi
%{_datadir}/agama/openapi/*.json

%files -n agama-scripts
%{_unitdir}/agama-scripts.service
%{_libexecdir}/agama-scripts.sh

%changelog
* Fri Dec 20 2024 Josef Reidinger <jreidinger@suse.com>
- Add bootloader.stopOnBootMenu section to profile to allow stop
  during boot for openQA (gh#agama-project/agama#1840)
* Thu Dec 19 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix several validation issues (gh#agama-project/agama#1845).
* Wed Dec 18 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Introduce a new AGAMA_LOG environment variable to control what to
  log (gh#agama-project/agama#1843).
* Wed Dec 18 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add jsonnet as a BuildRequires dependency because it is needed
  when running tests (gh#agama-project/agama#1842).
* Thu Dec 12 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix profile URL handling (bsc#1234362):
  - Follow redirections.
  - Determine the file format from the content instead of the
    extension. It does not apply to AutoYaST profiles, where it still
    uses the extension in the URL for backward compatibility.
* Tue Dec  3 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Do not refer to the agama-dbus-monitor because it is part of the
  Ruby package (gh#agama-project/agama#1805).
* Mon Dec  2 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Upgrade rustc dependency to version 1.81 because it is needed by
  zbus 5 (gh#agama-project/agama#1797).
* Sun Dec  1 2024 David Diaz <dgonzalez@suse.com>
- Rename flag to set password as encrypted
  (gh#agama-project/agama#1787).
* Fri Nov 29 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for running user-defined post-scripts in a chroot
  (gh#agama-project/agama#1792).
* Fri Nov 29 2024 Michal Filka <mfilka@suse.com>
- several improvements for CLI. agama logs store:
  - collects logs of agama-web-server service
  - collects list of installed packages (e.g. .packages.root or
    rpm -qa)
  - do not add into the archive empty files when log command
    returns nothing
  - do not explicitly set archive permissions on client side
  - do not hide backend errors (e.g. in case of invalid auth token)
- added service for monitoring Agama's D-Bus bus which stores
  errors into a log.
* Thu Nov 28 2024 Ladislav Slezák <lslezak@suse.com>
- Drop the handler for the "po.js" path in the HTTP server,
  the web frontend now uses dynamic imports for loading the
  translation files (gh#agama-project/agama#1777)
* Thu Nov 28 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for auto-installation "init" scripts
  (gh#agama-project/agama#1788).
* Mon Nov 25 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the default path of the D-Bus Questions object and the ISCSI
  Initiator interface (gh#agama-project/agama#1785).
* Fri Nov 15 2024 Ladislav Slezák <lslezak@suse.com>
- Allow using encrypted passord for root and the first user
  (gh#agama-project/agama#1771)
* Thu Nov 14 2024 Knut Alejandro Anderssen González <kanderssen@suse.com>
- Get some wireless settings as optional in order to not break the
  connections reader (gh#agama-project/agama#1753).
* Wed Nov 13 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Properly update the localization settings of the D-Bus services
  (bsc#1233159, bsc#1233160).
* Mon Nov 11 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add many missing elements to the OpenAPI spec
  (gh#agama-project/agama#1700).
- Update to utoipa 5.2 to generate the OpenAPI spec.
* Thu Nov  7 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Perform a system re-probing after executing pre-scripts
  (gh#agama-project/agama#1735).
* Mon Nov  4 2024 Michal Filka <mfilka@suse.com>
- Follow-up of original fix for gh#agama-project/agama#1495
- Implemented HTTP API for downloading logs
- Adapted CLI command "logs" to use the HTTP API for downloading logs
* Wed Oct 30 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add autoconnect property for network connections
  (gh#agama-project/agama#1715)
* Mon Oct 28 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use the correct method to apply the network configuration from
  the CLI (gh#agama-project/agama#1701).
* Wed Oct 23 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the action to download the logs (gh#agama-project/agama#1693).
* Tue Oct 22 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve OpenAPI specification generation (gh#agama-project/agama#1564):
  - Add a lot of missing elements to make the specification valid.
  - Use a xtask to generate the OpenAPI specification at build time.
  - Ship the specification in a separate package (agama-openapi).
* Wed Oct 16 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for running user-defined scripts before and after the
  installation (gh#agama-project/agama#1673).
* Wed Oct 16 2024 Michal Filka <mfilka@suse.com>
- Implemented option for providing remote API address for the CLI
  gh#agama-project/agama#1495
* Mon Oct 14 2024 Josef Reidinger <jreidinger@suse.com>
- CLI: change format for questions answers file from YAML to JSON
  to be consistent with other commands
  (gh#agama-project/agama#1667).
* Fri Sep 27 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Fix optional network settings (gh#agama-project/agama#1641).
* Fri Sep 27 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Expose keymaps localized descriptions (gh#agama-project/agama#1643).
* Wed Sep 25 2024 Clemens Famulla-Conrad <cfamullaconrad@suse.com>
- Rename wireless key-mgmt value wpa-eap-suite-b192 to
  wpa-eap-suite-b-192 (gh#agama-project/agama#1640)
* Fri Sep 20 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 10
* Fri Sep 20 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Change the license to GPL-2.0-or-later (gh#openSUSE/agama#1621).
* Wed Sep 18 2024 Josef Reidinger <jreidinger@suse.com>
- Expose the zFCP D-Bus API through HTTP (gh#openSUSE/agama#1570).
* Wed Sep 18 2024 Martin Vidner <mvidner@suse.com>
- For CLI, use HTTP clients instead of D-Bus clients,
  final piece: Storage (gh#openSUSE/agama#1600)
  - added StorageHTTPClient
* Fri Sep 13 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add additional wireless settings (gh#openSUSE/agama#1602).
* Tue Sep 10 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Implement 802.1x (EAP) in network settings (gh#openSUSE/agama#1597).
* Mon Sep  9 2024 Martin Vidner <mvidner@suse.com>
- For CLI, use HTTP clients instead of D-Bus clients,
  for Product (name and registration) (gh#openSUSE/agama#1548)
  - added ProductHTTPClient
* Thu Sep  5 2024 Lubos Kocman <lubos.kocman@suse.com>
- Show product logo in product selector (gh#openSUSE/agama#1415).
* Wed Aug 28 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Expose the DASD D-Bus API through HTTP (gh#openSUSE/agama#1532).
* Tue Aug 27 2024 José Iván López González <jlopez@suse.com>
- Schema definition for basic storage settings
  (gh#openSUSE/agama#1455).
* Mon Aug 26 2024 Martin Vidner <mvidner@suse.com>
- For CLI, use HTTP clients instead of D-Bus clients,
  for Software (gh#openSUSE/agama#1548)
  - added SoftwareHTTPClient
* Thu Aug 15 2024 Josef Reidinger <jreidinger@suse.com>
- Use sd_notify for starting agama-web-service to notify systemd
  when service is ready. It helps with race condition in agama-auto
  (gh#openSUSE/agama#1539)
- improve systemd dependencies of agama-web-service to ensure that
  agama service runs
* Fri Aug  9 2024 Martin Vidner <mvidner@suse.com>
- For CLI, use HTTP clients instead of D-Bus clients,
  for Users and Localization (gh#openSUSE/agama#1438)
  - service clients used by CLI:
  - added UsersHTTPClient, LocalizationHTTPClient
  - removed LocalizationClient
  - BaseHTTPClient API reworked:
  - return () or deserialized objects
  - added PUT and PATCH
  - web service:
  - PUT /api/users/first: do report backend errors
  - PATCH /api/users/root: report the (potential) backend errors
  - tests:
  - added tests using httpmock
  - env_logger added to dev-dependencies
* Mon Jul 22 2024 Josef Reidinger <jreidinger@suse.com>
- Fix `agama questions list` to list only unaswered questions and
  improve its performance
  (gh#openSUSE/agama#1476)
* Wed Jul 17 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add dns search domains and ignore-auto-dns to network settings
  (gh#openSUSE/agama#1330).
* Tue Jul 16 2024 Josef Reidinger <jreidinger@suse.com>
- CLI:
-- Add `agama questions list` to get list of unanswered questions
-- Add `agama questions ask` to ask for question and wait for
  answer
- agama-lib:
-- Add BaseHTTPClient that is base for clients that communicate
  with agama-web-server
  (gh#openSUSE/agama#1457)
* Wed Jul 10 2024 Josef Reidinger <jreidinger@suse.com>
- Add to HTTP API a method to remove questions
- Add to HTTP API method to get the answer to a question
  (gh#openSUSE/agama#1453)
* Wed Jul 10 2024 Josef Reidinger <jreidinger@suse.com>
- Add to HTTP API method POST for question to ask new question
  (gh#openSUSE/agama#1451)
* Fri Jul  5 2024 José Iván López González <jlopez@suse.com>
- Adapt storage model to changes in D-Bus API
  (gh#openSUSE/agama#1428).
* Mon Jul  1 2024 José Iván López González <jlopez@suse.com>
- Schema definition for guided and AutoYaST storage proposals
  (gh#openSUSE/agama#1263).
* Fri Jun 28 2024 Martin Vidner <mvidner@suse.com>
- Use gzip (.gz) instead of bzip2 (.bz2) to compress logs
  so that they can be attached to GitHub issues
  (gh#openSUSE/agama#1378)
* Thu Jun 27 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 9
* Thu Jun 27 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve the prompt to introduce the password in the "auth login"
  command (gh#openSUSE/agama#1271).
* Wed Jun 26 2024 Knut Anderssen <kanderssen@suse.com>
- Filter only external configured connections
  (gh#openSUSE/agama#1383).
- Expose more details about devices status in the API
  (gh#openSUSE/agama#1365).
* Wed Jun 26 2024 José Iván López González <jlopez@suse.com>
- Set and get storage config (gh#openSUSE/agama#1293).
* Tue Jun 25 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use the new SetLocale D-Bus method to change the language and the
  keyboard layout (gh#openSUSE/agama#1375).
* Tue Jun 25 2024 David Diaz <dgonzalez@suse.com>
- Add resize actions to storage model (gh#openSUSE/agama#1354).
* Fri Jun 21 2024 Clemens Famulla-Conrad <cfamullaconrad@suse.de>
- Add tun/tap model (gh#openSUSE/agama#1353)
* Thu Jun 20 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add a new "config edit" command allows editing installation
  settings using an external editor (gh#openSUSE/agama#1360).
- Remove the "--format" option (gh#openSUSE/agama#1360).
* Thu Jun 20 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for progress sequences with pre-defined descriptions
  (gh#openSUSE/agama#1356).
- Fix the "Progress" signal to use camelCase
  (gh#openSUSE/agama#1356).
* Fri Jun 14 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Remove references to the old "config add/set" subcommands
  (gh#openSUSE/agama/#1338).
* Thu Jun 13 2024 Knut Anderssen <kanderssen@suse.com>
- Apply network changes when connecting or disconnecting
  (gh#openSUSE/agama#1320).
* Thu Jun 13 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Expose Issues API in users-related interface
  (gh#openSUSE/agama#1202).
- Drop the old validations API.
* Wed Jun 12 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Allow writing to loopback connection in agama-server
  (gh#openSUSE/agama#1318).
* Tue Jun 11 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- CLI: use the master token /run/agama/token if available and
  readable (gh#openSUSE/agama#1287).
- CLI: remove the "config add/set" subcommands
  (gh#openSUSE/agama#1314).
* Mon Jun 10 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add mtu property for network connections
  (gh#openSUSE/agama#1101).
* Fri Jun  7 2024 Michal Filka <mfilka@suse.com>
- Improvements in HTTPS setup
  - self-signed certificate contains hostname
  - self-signed certificate is stored into default location
  - before creating new self-signed certificate a default location
    (/etc/agama.d/ssl) is checked for a certificate
  - gh#openSUSE/agama#1228
* Wed Jun  5 2024 José Iván López González <jlopez@suse.com>
- Process the legacyAutoyastStorage section of the profile
  (gh#openSUSE/agama#1284).
* Mon Jun  3 2024 Josef Reidinger <jreidinger@suse.com>
- CLI: Add new commands "agama download" and
  "agama profile autoyast" and remove "agama profile download" to
  separate common curl-like download and autoyast specific one
  which do conversion to json (gh#openSUSE/agama#1279)
* Wed May 29 2024 Josef Reidinger <jreidinger@suse.com>
- CLI: Add new command "agama profile import" that does the whole
  autoinstallation processing and loads the configuration
  (gh#openSUSE/agama#1270).
* Wed May 29 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve command-line interface help (gh#openSUSE/agama#1269 and
  (gh#openSUSE/agama#1273).
- agama-web-server connects to D-Bus only when needed
  (gh#openSUSE/agama#1273).
* Wed May 29 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- The HTTP request to perform a probing is not blocking anymore
  (gh#openSUSE/agama#1272).
* Mon May 27 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- The "agama auth" command reads the password from the standard
  input (gh#openSUSE/agama#1265).
* Mon May 27 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add agama.libssonnet to the spec file (gh#openSUSE/agama#1261).
* Thu May 23 2024 Ladislav Slezák <lslezak@suse.com>
- Avoid deadlock when "setxkbmap" call gets stucked, use a timeout
  (gh#openSUSE/agama#1249)
* Wed May 22 2024 Josef Reidinger <jreidinger@suse.com>
- autoinstallation jsonnet: Inject complete lshw json output and
  provide helper functions for filtering it (gh#openSUSE/agama#1242)
* Fri May 17 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 8
* Thu May 16 2024 Knut Anderssen <kanderssen@suse.com>
- Allow to download Agama logs through the manager HTTP API
  (gh#openSUSE/agama#1216).
* Thu May 16 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Restarting agama.service causes agama-web-server.service to be
  restarted too (gh#openSUSE/agama#1222).
* Thu May 16 2024 José Iván López González <jlopez@suse.com>
- Small changes in the storage HTTP API (gh#openSUSE/agama#1208):
  - /storage/proposal/usable_devices (get): returns a list of SIDs
    instead of device names.
  - /storage/proposal/settings (put): returns whether the proposal
    was successfully calculated.
* Thu May 16 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- The CLI does not fail when the storage proposal is missing
  (gh#openSUSE/agama#1220).
- Properly detect whether LVM is activated.
* Thu May 16 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Change the web server to listen on port 80 by default
  (gh#openSUSE/agama#1217).
* Wed May 15 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve logging in the D-Bus and web servers
  (gh#openSUSE/agama#1215):
  - Write to the stdout if they are not connected to
    systemd-journald.
  - The stdout logger includes the file/line (it was already
    included when logging to systemd-journald).
* Wed May 15 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Do not crash if the /etc/agama.d/locales file does not contain
  any valid locale (gh#openSUSE/agama#1213).
* Tue May 14 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- If present, read the locales list from the /etc/agama.d/locales
  file (gh#openSUSE/agama#1205).
* Tue May 14 2024 Knut Anderssen <kanderssen@suse.com>
- Dropped the network D-Bus service as it is not needed anymore
  (gh#openSUSE/agama#1199).
* Mon May 13 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Extend the storage HTTP API to support handling the iSCSI
  configuration (gh#openSUSE/agama#1187).
* Mon May 13 2024 José Iván López González <jlopez@suse.com>
- Provide HTTP API for storage (gh#openSUSE/agama#1175).
* Mon May  6 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Extend the HTTP/JSON API:
  - Localization (gh#openSUSE/agama#1047, gh#openSUSE/agama#1120).
  - Networking (gh#openSUSE/agama#1064).
  - Software (gh#openSUSE/agama#1069).
  - Manager service (gh#openSUSE/agama#1089).
  - Questions (gh#openSUSE/agama#1091).
  - Progress interface (gh#openSUSE/agama#1092).
  - Issues interface (gh#openSUSE/agama#1100).
  - Users (gh#openSUSE/agama#1117).
  - Product registration (gh#openSUSE/agama#1146).
- Add an "agama-web-server" service (gh#openSUSE/agama/1119).
- Fix the generation of the self-signed certificate
  (gh#openSUSE/agama#1131).
- Improve agama-server logging (gh#openSUSE/agama#1143).
- Provide frontend translations via the /po.js path
  (gh#openSUSE/agama#1126).
* Wed Mar 13 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add infiniband to network model (gh#openSUSE/agama#1032).
* Thu Mar  7 2024 Michal Filka <mfilka@suse.com>
- CLI: added auth command with login / logout / show subcommands
  for handling authentication token management with new agama web
  server
* Thu Feb 29 2024 Ladislav Slezák <lslezak@suse.com>
- Web server:
  - Accept also IPv6 connections (gh#openSUSE/agama#1057)
  - Added SSL (HTTPS) support (gh#openSUSE/agama#1062)
  - Use either the cerfificate specified via command line
    arguments or generate a self-signed certificate
  - Redirect external HTTP requests to HTTPS
  - Allow HTTP for internal connections (http://localhost)
  - Optionally listen on a secondary address
    (to allow listening on both HTTP/80 and HTTPS/433 ports)
* Tue Feb 27 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Reorganize RPM packages (gh#openSUSE/agama#1056):
  * agama is now the main package and it contains agama-dbus-server
    and agama-web-server.
  * agama-cli is a subpackage.
* Wed Feb  7 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add preliminary support to import AutoYaST profiles
  (gh#openSUSE/agama#1029).
* Mon Jan 29 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Better network configuration handling (gh#openSUSE/agama#1006):
  * Write only changed connections.
  * Roll back when updating the NetworkManager configuration
    failed.
  * Improved error handling when reading or writing the changes.
  * Properly remove deleted connections from the D-Bus tree.
  * Use the UUID to identify connections.
  * Do not support multiple connections with the same ID.
* Mon Jan 29 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add hidden property for wireless in network model
  (gh#openSUSE/agama#1024).
* Mon Jan 29 2024 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add more wireless options to network model
  (gh#openSUSE/agama#1014).
* Tue Jan 23 2024 Clemens Famulla-Conrad <cfamullaconrad@suse.de>
- Add Bridge model (gh#openSUSE/agama#1008)
* Tue Jan 23 2024 Clemens Famulla-Conrad <cfamullaconrad@suse.de>
- Add VLAN model (gh#openSUSE/agama#918)
* Thu Jan 11 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Include the encoding as part of the locales (gh#openSUSE/agama#987).
* Mon Jan  8 2024 José Iván López González <jlopez@suse.com>
- Fix the list of keymaps to avoid duplicated values
  (gh#openSUSE/agama#981).
* Thu Dec 21 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 7
* Thu Dec 21 2023 Ancor Gonzalez Sosa <ancor@suse.com>
- The result of ListTimezones includes the localized country name
  for each timezone (gh#openSUSE/agama#946)
* Fri Dec 15 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update agama-cli dependencies including the zerocopy crate to
  address a security alert (see gh#google/zerocopy#716).
* Wed Dec 13 2023 Knut Anderssen <kanderssen@suse.com>
- Add support for bonding connections (gh#openSUSE/agama#885).
* Fri Dec  8 2023 Josef Reidinger <jreidinger@suse.com>
- Change the config in a way that: (gh#openSUSE/agama#919)
  1. product is moved to own section and is now under product.id
  2. in product section is now also registrationCode and registrationEmail
  3. in software section is now patterns to select patterns to install
- adapt profile.schema according to above changes
- org.opensuse.Agama.Software1 API changed to report missing patterns
* Tue Dec  5 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add ability to assign a custom MAC address for network
  connections (gh#openSUSE/agama#893)
* Tue Dec  5 2023 José Iván López González <jlopez@suse.com>
- Explicitly add dependencies instead of relying on the live ISO
  to provide the required packages (gh#openSUSE/agama/911).
* Tue Dec  5 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add support for dummy network devices although they are not
  exposed on D-Bus yet (gh#openSUSE/agama#913).
* Sun Dec  3 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single call to systemd-firstboot to write the localization
  settings (gh#openSUSE/agama#903).
* Sat Dec  2 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 6
* Wed Nov 29 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Rework the org.opensuse.Agama1.Locale interface
  (gh#openSUSE/agama#881):
  * Replace LabelsForLocales function with ListLocales.
  * Add a ListKeymaps function.
  * Extend the ListTimezone function to include the translation of
    each part.
  * Drop ListUILocales and ListVConsoleKeyboards functions.
  * Remove the SupportedLocales and VConsoleKeyboard properties.
  * Do not read the lists of locales, keymaps and timezones on
    each request.
  * Peform some validation when trying to change the Locales,
    Keymap and Timezone properties.
* Thu Nov 16 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update dependencies to compatible versions
  (gh#openSUSE/agama#874).
- Replace tempdir with tempfile to prevent RUSTSEC-2023-0018.
* Wed Nov 15 2023 José Iván López González <jlopez@suse.com>
- Adapt to changes in software D-Bus API (gh#openSUSE/agama#869).
* Wed Nov 15 2023 Michal Filka <mfilka@suse.com>
- Improved "agama logs store" (gh#openSUSE/agama#823)
  - added an option which allows to define the archive destination
* Tue Nov 14 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add support for routing to the network model (gh#openSUSE/agama#824)
* Mon Oct 23 2023 Michal Filka <mfilka@suse.com>
- Improved "agama logs store" (gh#openSUSE/agama#812)
  - the archive file owner is root:root
  - the permissions is set to r/w for the owner
* Mon Oct 23 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 5
* Tue Oct 10 2023 Michal Filka <mfilka@suse.com>
- Improve file and directory names in "agama logs store".
- Add an "agama logs list" subcommand.
* Tue Sep 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 4
* Tue Sep 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Wait until the manager is ready before probing
  (gh#openSUSE/agama#771).
* Mon Sep 25 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for IPv6 network settings (gh#openSUSE/agama#761).
* Mon Sep 25 2023 Michal Filka <mfilka@suse.com>
- CLI: added (sub)commands for handling logs. "store" subcommand is
  similar to what old save_y2logs did. (gh#openSUSE/agama#757)
* Tue Sep 19 2023 José Iván López González <jlopez@suse.com>
- Adapt to new storage D-Bus API and explicitly call to probe after
  selecting a new product (gh#openSUSE/agama#748).
* Thu Sep 14 2023 Josef Reidinger <jreidinger@suse.com>
- Improve questions CLI help text (gh#openSUSE/agama#754)
* Thu Sep 14 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single D-Bus service to connect to the manager and the
  users API (gh#openSUSE/agama#753, follow-up of
  gh#openSUSE/agama#729).
* Wed Sep 13 2023 Knut Anderssen <kanderssen@suse.com>
- Allow to bind a connection to an specific interface through its
  name or through a set of match settings (gh#opensSUSE/agama#723).
* Thu Aug 31 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single D-Bus service to expose locale, network and
  questions settings (gh#openSUSE/agama#729).
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.com>
- Locale service: add value for UI locale (gh#openSUSE/agama#725)
* Thu Aug  3 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Move the settings functionality to a separate package,
  agama-settings (gh#openSUSE/agama#666).
- Make the "Settings" derive macro reusable from other crates.
- Extend the "Settings" derive macro to generate code for
  InstallSettings and NetworkSettings.
- Improve error reporting when working with the "config"
  subcommand.
* Wed Aug  2 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 3
* Wed Jul 26 2023 Josef Reidinger <jreidinger@suse.com>
- CLI: add to "questions" command "answers" subcommand to set
  file with predefined answers
- dbus-server: add "AddAnswersFile" method to Questions service
  (gh#openSUSE/agama#669)
* Tue Jul 18 2023 Josef Reidinger <jreidinger@suse.com>
- Add to CLI "questions" subcommand with mode option to set
  interactive and non-interactive mode (gh#openSUSE/agama#668)
* Mon Jul 17 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the logic to decide which network connections to write
  due to a bug introduced in gh#openSUSE/agama#662
  (gh#openSUSE/agama#667).
* Mon Jul 17 2023 Josef Reidinger <jreidinger@suse.com>
- Adapt to new questions D-Bus API to allow automatic answering of
  questions when requested (gh#openSUSE/agama#637, reverts
  gh#openSUSE/agama#649 as now default option is mandatory)
* Thu Jul 13 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve error reporting in the command-line interface
  (gh#openSUSE/agama#659 and gh#openSUSE/agama#660).
* Thu Jul 13 2023 José Iván López González <jlopez@suse.com>
- Read the storage candidate devices and show them with
  "agama config show" (gh#openSUSE/agama#658).
* Fri Jul  7 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve the progress reporting (gh#openSUSE/agama#653).
* Thu Jul  6 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve the waiting logic and implement a retry mechanism for the
  "agama install" command (bsc#1213047).
* Wed Jul  5 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the questions service to handle questions with no default
  option (gh#openSUSE/agama#649).
* Thu Jun  1 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add a localization D-Bus service (gh#openSUSE/agama#533).
- Add a network D-Bus service (gh#openSUSE/agama#571).
* Tue May 23 2023 Martin Vidner <mvidner@suse.com>
- Version 2.1
* Mon May 22 2023 Martin Vidner <mvidner@suse.com>
- Version 2
* Thu May 11 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Import root authentication settings when reading a Jsonnet file
  (bsc#1211300, gh#openSUSE/agama#573).
- Do not export the SSH public key as an empty string when it is
  not defined.
* Fri Mar 24 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.2:
  * Add validation for software and users settings
    (gh#yast/agama-cli#48, gh#yast/agama-cli#51).
  * Better error reporting when the bus is not found
    (gh#yast/agama-cli#48).
  * Improve the progress reporting mechanism, although it is still
    a work in progress (gh#yast/agama-cli#50).
* Wed Mar 22 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for setting root authentication mechanisms
  (gh#yast/agama-cli#47).
* Tue Mar 21 2023 Martin Vidner <mvidner@suse.com>
- Do not fall back to the system D-Bus (gh#yast/agama-cli#45).
* Tue Mar 21 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use JSON as the default format (gh#yast/agama-cli#46).
* Tue Mar 21 2023 Josef Reidinger <jreidinger@suse.com>
- Fix the path of the JSON schema (gh#yast/agama-cli#44).
* Thu Mar 16 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- First version of the package:
  * Querying and setting simple values.
  * Adding elements to collections
  * Handling of auto-installation profiles.
  * Basic error handling
- 0.1
